--- init.d.lsb.ex.orig	2007-10-16 21:20:29.000000000 +0200
+++ init.d.lsb.ex	2007-10-16 22:28:07.000000000 +0200
@@ -58,6 +58,15 @@
                         # If this value is set too low you might not
                         # let some servers to die gracefully and
                         # 'restart' will not work
+
+#STARTIME=2             # Time to wait for the server to start, in seconds
+                        # If this value is set each time the server is
+                        # started (on start or restart) the script will
+                        # stall to try to determine if it is running
+                        # If it is not set and the server takes time
+                        # to setup a pid file the log message might 
+                        # be a false positive (says it did not start
+                        # when it actually did)
                         
 LOGFILE=$LOGDIR/$NAME.log  # Server logfile
 #DAEMONUSER=#PACKAGE#   # Users to run the daemons as. If this value
@@ -185,15 +194,20 @@
             log_end_msg 0
             exit 0
         fi
-        if start_server && running ;  then
-            # It's ok, the server started and is running
-            log_end_msg 0
-        else
-            # Either we could not start it or it is not running
-            # after we did
+        if start_server ; then
             # NOTE: Some servers might die some time after they start,
-            # this code does not try to detect this and might give
-            # a false positive (use 'status' for that)
+            # this code will detect this issue if STARTTIME is set
+            # to a reasonable value
+            [ -n "$STARTTIME" ] && sleep $STARTTIME # Wait some time 
+            if  running ;  then
+                # It's ok, the server started and is running
+                log_end_msg 0
+            else
+                # It is not running after we did start
+                log_end_msg 1
+            fi
+        else
+            # Either we could not start it
             log_end_msg 1
         fi
 	;;
@@ -226,6 +240,7 @@
         # Wait some sensible amount, some server need this
         [ -n "$DIETIME" ] && sleep $DIETIME
         start_server
+        [ -n "$STARTTIME" ] && sleep $STARTTIME
         running
         log_end_msg $?
 	;;
